# \SecurityObjectsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**ActivateSecurityObject**](SecurityObjectsApi.md#ActivateSecurityObject) | **Post** /crypto/v1/keys/{key-id}/activate | Transitions immediately a security object to Active state
[**AgreeKey**](SecurityObjectsApi.md#AgreeKey) | **Post** /crypto/v1/agree | Agree on a key from two other keys
[**DeletePrivateKey**](SecurityObjectsApi.md#DeletePrivateKey) | **Delete** /crypto/v1/keys/{key-id}/private | Remove / Destroy private half of the asymmetric key
[**DeleteSecurityObject**](SecurityObjectsApi.md#DeleteSecurityObject) | **Delete** /crypto/v1/keys/{key-id} | Delete a security object
[**DeriveKey**](SecurityObjectsApi.md#DeriveKey) | **Post** /crypto/v1/keys/{key-id}/derive | Derive a key from another key
[**DeriveKeyEx**](SecurityObjectsApi.md#DeriveKeyEx) | **Post** /crypto/v1/derive | Derive a key from another key
[**GenerateSecurityObject**](SecurityObjectsApi.md#GenerateSecurityObject) | **Post** /crypto/v1/keys | Generate a new security object
[**GetSecurityObject**](SecurityObjectsApi.md#GetSecurityObject) | **Get** /crypto/v1/keys/{key-id} | Get a specific security object
[**GetSecurityObjectDigest**](SecurityObjectsApi.md#GetSecurityObjectDigest) | **Post** /crypto/v1/keys/digest | Retrieve the digest (hash) of the value of an exportable security object
[**GetSecurityObjectValue**](SecurityObjectsApi.md#GetSecurityObjectValue) | **Get** /crypto/v1/keys/{key-id}/export | Retrieve the value of an exportable security object
[**GetSecurityObjectValueEx**](SecurityObjectsApi.md#GetSecurityObjectValueEx) | **Post** /crypto/v1/keys/export | Retrieve the value of an exportable security object
[**GetSecurityObjects**](SecurityObjectsApi.md#GetSecurityObjects) | **Get** /crypto/v1/keys | Get all security objects
[**ImportSecurityObject**](SecurityObjectsApi.md#ImportSecurityObject) | **Put** /crypto/v1/keys | Import a security object
[**PersistSecurityObject**](SecurityObjectsApi.md#PersistSecurityObject) | **Post** /crypto/v1/keys/persist | Persist a transient key.
[**RevokeSecurityObject**](SecurityObjectsApi.md#RevokeSecurityObject) | **Post** /crypto/v1/keys/{key-id}/revoke | Transitions immediately a security object to Deactivated or Compromised state
[**RotateSecurityObject**](SecurityObjectsApi.md#RotateSecurityObject) | **Post** /crypto/v1/keys/rekey | Rotate a key.
[**UpdateSecurityObject**](SecurityObjectsApi.md#UpdateSecurityObject) | **Patch** /crypto/v1/keys/{key-id} | Update a security object


# **ActivateSecurityObject**
> ActivateSecurityObject(ctx, keyId)
Transitions immediately a security object to Active state

Trigger the transition of a security object to Active state. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **keyId** | **string**| kid of security object | 

### Return type

 (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **AgreeKey**
> KeyObject AgreeKey(ctx, body)
Agree on a key from two other keys

This does a cryptographic key agreement operation between a public and private key. Both keys must have been generated from the same parameters (e.g. the same elliptic curve). Both keys must allow the AGREEKEY operation. The request body contains the requested properties for the new key as well as the mechanism (e.g. Diffie-Hellman) to be used to produce the key material for the new key. The output of this API should not be used directly as a cryptographic key. The target object type should be HMAC or Secret, and a key derivation procedure should be used to derive the actual key material. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **body** | [**AgreeKeyRequest**](AgreeKeyRequest.md)| Template of the agreed-upon security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **DeletePrivateKey**
> DeletePrivateKey(ctx, keyId)
Remove / Destroy private half of the asymmetric key

Removes the private portion of an asymmetric key from SDKMS. After this operation is performed, operations that require the private key, such as encryption and generating signatures, may no longer be performed. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **keyId** | **string**| kid of security object | 

### Return type

 (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **DeleteSecurityObject**
> DeleteSecurityObject(ctx, keyId)
Delete a security object

Delete a specified security object.

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **keyId** | **string**| kid of security object | 

### Return type

 (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **DeriveKey**
> KeyObject DeriveKey(ctx, keyId, body)
Derive a key from another key

This derives a key from an existing key and returns the properties of the new key. The request body contains the requested properties for the new as well as the mechanism to be used to produce the key material for the new key. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **keyId** | **string**| kid of security object | 
  **body** | [**DeriveKeyRequest**](DeriveKeyRequest.md)| Name of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **DeriveKeyEx**
> KeyObject DeriveKeyEx(ctx, body)
Derive a key from another key

This derives a key from an existing key and returns the properties of the new key. The request body contains the requested properties for the new as well as the mechanism to be used to produce the key material for the new key. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **body** | [**DeriveKeyRequestEx**](DeriveKeyRequestEx.md)| Name of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **GenerateSecurityObject**
> KeyObject GenerateSecurityObject(ctx, body)
Generate a new security object

Generate a new security object (such as an RSA key pair or an AES key) of the requested size or elliptic curve. <br> By default, all key operations except for Export that are implemented for that type of key will be enabled. These may be overridden by requesting specific operations in the key creation request. <br> Objects of type Opaque may not be generated with this API. They must be imported via the importSecurityObject API. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **body** | [**SobjectRequest**](SobjectRequest.md)| Request to create, update, or import security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **GetSecurityObject**
> KeyObject GetSecurityObject(ctx, keyId)
Get a specific security object

Get the details of a particular security object. The query parameter `?view=value` may be used to get the value of an opaque object or certificate directly as raw bytes. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **keyId** | **string**| kid of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **GetSecurityObjectDigest**
> DigestResponse GetSecurityObjectDigest(ctx, body)
Retrieve the digest (hash) of the value of an exportable security object

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **body** | [**ObjectDigestRequest**](ObjectDigestRequest.md)| Object digest request | 

### Return type

[**DigestResponse**](DigestResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **GetSecurityObjectValue**
> KeyObject GetSecurityObjectValue(ctx, keyId)
Retrieve the value of an exportable security object

Get the details and value of a particular exportable security object. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **keyId** | **string**| kid of security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **GetSecurityObjectValueEx**
> KeyObject GetSecurityObjectValueEx(ctx, body)
Retrieve the value of an exportable security object

Get the details and value of a particular exportable security object. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **body** | [**SobjectDescriptor**](SobjectDescriptor.md)| Request to export a security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **GetSecurityObjects**
> []KeyObject GetSecurityObjects(ctx, optional)
Get all security objects

Return detailed information about the security objects stored in Fortanix SDKMS. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
 **optional** | **map[string]interface{}** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a map[string]interface{}.

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **string**| Only retrieve the security object with this name. | 
 **groupId** | **string**| Only retrieve security objects in the specified group. | 
 **creator** | **string**| Only retrieve security objects created by the user or application with the specified id. | 
 **sort** | **string**| This specifies the property (&#x60;kid&#x60; or &#x60;name&#x60;) and order (ascending or descending) with which to sort the security objects. By default, security objects are sorted by &#x60;kid&#x60; in ascending order. The syntax is \&quot;&lt;property&gt;:[asc|desc]\&quot; (e.g. \&quot;kid:desc\&quot;) or just \&quot;&lt;property&gt;\&quot; (ascending order by default).  | 
 **start** | **string**| If provided, this must be a value of the property specified in &#x60;sort&#x60;. Returned security objects will begin just above or just below this value (for asc/desc order resp.).  | 
 **limit** | **int32**| Maximum number of security objects to return. If not provided, the limit is 100. | 
 **offset** | **int32**| Number of security objects past &#x60;start&#x60; to skip. | 

### Return type

[**[]KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **ImportSecurityObject**
> KeyObject ImportSecurityObject(ctx, body)
Import a security object

Import a security object into SDKMS. <br> By default, all key operations except that are implemented for that type of key will be enabled. These may be overridden by requesting specific operations in the key import request. <br> For symmetric and asymmetric keys, value is base64-encoding of the key material in DER format. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **body** | [**SobjectRequest**](SobjectRequest.md)| Request to create, update, or import security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **PersistSecurityObject**
> KeyObject PersistSecurityObject(ctx, body)
Persist a transient key.

This API copies a transient key into a persisted security object in SDKMS. If the transient key's origin is \"FortanixHSM\", the origin of the persisted key will be \"Transient\". If the transient key's origin is \"External\", the origin of the persisted key will be \"External\". 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **body** | [**PersistTransientKeyRequest**](PersistTransientKeyRequest.md)| Persist transient key request | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **RevokeSecurityObject**
> RevokeSecurityObject(ctx, keyId, body)
Transitions immediately a security object to Deactivated or Compromised state

Trigger the transition of a security object to Deactivated or Compromised state depending on the RevocationReason Code. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **keyId** | **string**| kid of security object | 
  **body** | [**RevocationReason**](RevocationReason.md)| Reason to revoke a security object | 

### Return type

 (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **RotateSecurityObject**
> KeyObject RotateSecurityObject(ctx, body)
Rotate a key.

Rotate an existing security object.

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **body** | [**SobjectRequest**](SobjectRequest.md)| Request to create, update, or import security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **UpdateSecurityObject**
> KeyObject UpdateSecurityObject(ctx, keyId, body)
Update a security object

Update the properties of a security object. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for logging, tracing, authentication, etc.
  **keyId** | **string**| kid of security object | 
  **body** | [**SobjectRequest**](SobjectRequest.md)| Request to create, update, or import security object | 

### Return type

[**KeyObject**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

