/*
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations. 
 *
 * API version: 1.0.0-20200319
 * Contact: support@fortanix.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package sdkms



type SobjectRequest struct {
	// Name of the security object to create or import. Security object names must be unique within an account.
	Name string `json:"name"`

	// Description of the security object to create or import.
	Description string `json:"description,omitempty"`

	// Size in bits (not bytes) of the security object to create or import. Required for symmetric keys. Deprecated for RSA keys, specify it in `RsaOptions` instead.
	KeySize int32 `json:"key_size,omitempty"`

	// For RSA keys only. Deprecated. Specify in `RsaOptions` instead. Public exponent to use when generating an RSA key.
	PubExponent int32 `json:"pub_exponent,omitempty"`

	EllipticCurve *EllipticCurve `json:"elliptic_curve,omitempty"`

	Rsa *RsaOptions `json:"rsa,omitempty"`

	Fpe *FpeOptions `json:"fpe,omitempty"`

	// Group ID (not name) of the security group that this security object should belong to. The user or application creating this security object must be a member of this group. If no group is specified, the default group for the user or application will be used. 
	GroupId string `json:"group_id,omitempty"`

	ObjType *ObjectType `json:"obj_type"`

	// Optional array of key operations to be enabled for this security object. If this property is not provided, the SDKMS server will provide a default set of key operations. Note that if you provide an empty array, all key operations will be disabled. 
	KeyOps []KeyOperations `json:"key_ops,omitempty"`

	// User-defined metadata for this key. Stored as key-value pairs.
	CustomMetadata map[string]string `json:"custom_metadata,omitempty"`

	// When importing a security object, this field contains the binary contents to import. When creating a security object, this field is unused. The value of an OPAQUE or CERTIFICATE object is always returned. For other objects, the value is returned only with `/crypto/v1/keys/export` API (if the object is exportable). 
	Value string `json:"value,omitempty"`

	// Whether the new security object should be enabled. Disabled security objects may not perform cryptographic operations. 
	Enabled bool `json:"enabled,omitempty"`

	// If this is true, SDKMS will create a transient key.
	Transient bool `json:"transient,omitempty"`

	DeterministicSignatures bool `json:"deterministic_signatures,omitempty"`
}


